@@ -7,6 +7,7 @@
 #### R package mixture: Mixture Models for Clustering and Classification
 ################################
 
+
 rmixcomp <- function(n, prob, mu, sigma, type = "alr") {
   ## n is the sample size
   ## p is a vector with the mixing probabilities
@@ -21,20 +22,21 @@ rmixcomp <- function(n, prob, mu, sigma, type = "alr") {
   nu <- as.vector(table(ina))  ## frequency table of each cluster
   y <- array(dim = c(n, p, g))
   for (j in 1:g) {
-    y[1:nu[j], , j] <- MASS::mvrnorm( nu[j], mu[j, ], sigma[ , , j])
+    y[1:nu[j], , j] <- rmvnorm( nu[j], mu[j, ], sigma[ , , j]) 
   }
   x <- y[1:nu[1], , 1]
   for (j in 2:g) {
     x <- rbind(x, y[1:nu[j], , j])
-  }
-  if (type == "alr") {
-    x1 <- cbind(1, exp(x) )
-    x <- x1 / rowSums(x1)
+  }  
+  if (type == "alr") { 
+    x1 <- cbind(1, exp(x) ) 
+    x <- x1 / rowSums(x1) 
   } else {
-    x1 <- x %*% helm(p+1)
-    x <- exp(x1) / rowSums( exp(x1) )
+    x1 <- tcrossprod( x, helm( p + 1) )
+    x2 <- exp(x1)
+    x <- x2 / rowSums( x2 ) 
   }
   ## x is the simulated data
   ## data come from the first cluster, then from the second and so on
   list(id = ina, x = x)
-}
+}
\ No newline at end of file
